@@ -6,10 +6,10 @@ use fil_actors_runtime::runtime::{ActorCode, Runtime};
 use fil_actors_runtime::{
     actor_error, wasm_trampoline, ActorDowncast, ActorError, SYSTEM_ACTOR_ADDR,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::RawBytes;
 use fvm_shared::actor::builtin::Type;
 use fvm_shared::address::Address;
-use fvm_shared::blockstore::Blockstore;
-use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::{ActorID, MethodNum, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
@@ -46,7 +46,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(sys_ref))?;
         let state = State::new(rt.store(), params.network_name).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 "failed to construct init actor state",
             )
         })?;
@@ -70,7 +70,7 @@ impl Actor {
             .get_actor_code_cid(&rt.message().caller())
             .ok_or_else(|| {
                 actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "no code for caller as {}",
                     rt.message().caller()
                 )
@@ -79,7 +79,7 @@ impl Actor {
         log::trace!("caller code CID: {:?}", &caller_code);
 
         if !can_exec(rt, &caller_code, &params.code_cid) {
-            return Err(actor_error!(ErrForbidden;
+            return Err(actor_error!(USR_FORBIDDEN;
                     "called type {} cannot exec actor type {}",
                     &caller_code, &params.code_cid
             ));
@@ -98,7 +98,7 @@ impl Actor {
         let id_address: ActorID = rt.transaction(|s: &mut State, rt| {
             s.map_address_to_new_id(rt.store(), &robust_address)
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to allocate ID address")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to allocate ID address")
                 })
         })?;
 
@@ -140,7 +140,7 @@ impl ActorCode for Actor {
                 let res = Self::exec(rt, rt.deserialize_params(params)?)?;
                 Ok(RawBytes::serialize(res)?)
             }
-            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
+            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
         }
     }
 }
